==> camunda-engine-7.8.0-alpha2-sources.jar: org/camunda/bpm/engine/impl/history/event/HistoricIdentityLinkLogEventEntity.java <==
package org.camunda.bpm.engine.impl.history.event;

import java.util.Date;
/**
 * 
 * @author Deivarayan Azhagappan
 *
 */
public class HistoricIdentityLinkLogEventEntity extends HistoryEvent {

  private static final long serialVersionUID = 1L;

  protected Date time;

  protected String type;

  protected String userId;

  protected String groupId;

  protected String taskId;

  protected String operationType;

  protected String assignerId;

  protected String tenantId;

  public Date getTime() {
    return time;
  }

  public void setTime(Date time) {
    this.time = time;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public String getUserId() {
    return userId;
  }

  public void setUserId(String userId) {
    this.userId = userId;
  }

  public String getGroupId() {
    return groupId;
  }

  public void setGroupId(String groupId) {
    this.groupId = groupId;
  }

  public String getTaskId() {
    return taskId;
  }

  public void setTaskId(String taskId) {
    this.taskId = taskId;
  }

  public String getOperationType() {
    return operationType;
  }

  public void setOperationType(String operationType) {
    this.operationType = operationType;
  }

  public String getAssignerId() {
    return assignerId;
  }

  public void setAssignerId(String assignerId) {
    this.assignerId = assignerId;
  }
  
  public String getTenantId() {
    return tenantId;
  }

  public void setTenantId(String tenantId) {
    this.tenantId = tenantId;
  }
}

==> camunda-engine-7.11.0-alpha2-sources.jar: org/camunda/bpm/engine/impl/history/event/HistoricIdentityLinkLogEventEntity.java <==
/*
 * Copyright © 2013-2018 camunda services GmbH and various authors (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.history.event;

import java.util.Date;
/**
 * 
 * @author Deivarayan Azhagappan
 *
 */
public class HistoricIdentityLinkLogEventEntity extends HistoryEvent {

  private static final long serialVersionUID = 1L;

  protected Date time;

  protected String type;

  protected String userId;

  protected String groupId;

  protected String taskId;

  protected String operationType;

  protected String assignerId;

  protected String tenantId;

  public Date getTime() {
    return time;
  }

  public void setTime(Date time) {
    this.time = time;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public String getUserId() {
    return userId;
  }

  public void setUserId(String userId) {
    this.userId = userId;
  }

  public String getGroupId() {
    return groupId;
  }

  public void setGroupId(String groupId) {
    this.groupId = groupId;
  }

  public String getTaskId() {
    return taskId;
  }

  public void setTaskId(String taskId) {
    this.taskId = taskId;
  }

  public String getOperationType() {
    return operationType;
  }

  public void setOperationType(String operationType) {
    this.operationType = operationType;
  }

  public String getAssignerId() {
    return assignerId;
  }

  public void setAssignerId(String assignerId) {
    this.assignerId = assignerId;
  }
  
  public String getTenantId() {
    return tenantId;
  }

  public void setTenantId(String tenantId) {
    this.tenantId = tenantId;
  }

  public String getRootProcessInstanceId() {
    return rootProcessInstanceId;
  }

  public void setRootProcessInstanceId(String rootProcessInstanceId) {
    this.rootProcessInstanceId = rootProcessInstanceId;
  }

}
